[−][src]Trait aimc_hal::messaging::Handler
Something which can handle a request and generate a response.
Associated Types
type Response
The type of response.
Something which can handle a request and generate a response.
type ResponseThe type of response.